@@ -64,11 +64,15 @@ def create(project_name: str = typer.Argument("magic-server"), replace: bool = F
 
 @app.command()
 def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
+    print("exec", sys.executable)
+    """
     prefix = getattr(sys, "prefix", "")
     base_prefix = getattr(sys, "base_prefix", "")
 
     print("prefix", prefix, "\nbase_prefix", base_prefix)
-
+    print("which python")
+    os.system("which python")
+    """
     main_filename = "main.py"
     if not Path(main_filename).exists():
         typer.echo(
